@@ -228,6 +228,12 @@ class HgImplementation(M.RepositoryImplementation):
             if id_only:
                 yield ctx.hex()
             else:
+                rename_details = {}
+                if path and path in ctx.files() and ctx[path].renamed():
+                    rename_details['path'] = '/' + ctx[path].renamed()[0]
+                    rename_details['commit_url'] = self._repo.url_for_commit(
+                        ctx.hex()
+                    )
                 user = ctx.user()
                 match = self.re_hg_user.match(user)
                 if match:
@@ -250,7 +256,11 @@ class HgImplementation(M.RepositoryImplementation):
                         'refs': branches[ctx.hex()] + ctx.tags(),
                         'parents': [pctx.hex() for pctx in ctx.parents() if pctx.rev() > -1],
                         'size': int(ctx[path].size()) if path in ctx else None,
+                        'rename_details': rename_details,
                     }
+                if rename_details:
+                    # we do not need to show commits before rename
+                    break
 
     def open_blob(self, blob):
         fctx = self._hg[blob.commit._id][h.really_unicode(blob.path()).encode('utf-8')[1:]]
